@@ -14,9 +14,8 @@ use Storable qw(dclone);
 BEGIN {
     use Exporter ();
     our ( $VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-    $VERSION = "0.1";
+    $VERSION = "0.01";
 
-    #$AUTHOR  = "Vilas Menon(vilas\@fiserlab.org )";
     @ISA = qw(Exporter);
 
     #Name of the functions to export
@@ -50,21 +49,21 @@ our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
-	Module for enumerating combinations of Smotifs to generate full protein models
-	
-    	Usage:
+    Module for enumerating combinations of Smotifs to generate full protein models
 
-	    use EnumerateSmotifCombinations;
+    Usage:
 
-    	EnumerateSmotifCombinations($pdbcode,$mot,$havestructure);
+    use EnumerateSmotifCombinations;
+
+    EnumerateSmotifCombinations($pdbcode,$mot,$havestructure);
 
 =head1 EXPORT
 
-	enumerate
+    enumerate
     full_enum
-	prepare_for_enumeration
-	pre_gen_list
-	gen_list
+    prepare_for_enumeration
+    pre_gen_list
+    gen_list
 
 =head2 prepare_for_enumeration
 	
@@ -221,9 +220,8 @@ Explanation:
 sub enumerate {
     use File::Spec::Functions qw(catfile);
 
-    my ( $pdbcode, $chain, $mot1, $havestructure ) = @_;
+    my ( $pdbcode, $mot1, $havestructure ) = @_;
     croak "4-letter pdb code is required" unless $pdbcode;
-    croak "Chain ID is required" unless $chain;
     croak "Subset list of smotifs is required" unless ($mot1);
     $havestructure = 0 unless $havestructure;
 
@@ -254,18 +252,6 @@ sub enumerate {
     my $base = SmotifTF::Protein->new();
     my @data;
 
-    #Check to see relevant files and directories exist
-
-    my $pdbfilename =
-      SmotifTF::GeometricalCalculations::get_full_path_name_for_pdb_code($pdbcode, $chain);
-
-    # print " pdbfilename = $pdbfilename\n";
-    if ( $havestructure == 1 ) {
-        unless ( -e $pdbfilename ) {
-            croak "No pdb file $pdbfilename for $pdbcode\n";
-        }
-    }
-
     #Open the file containing info about the Smotif types, starting points,
     #and secondary structure and loop lengths of Smotifs in the query protein
     my $seq = '';
@@ -596,18 +582,14 @@ sub get_dd_info {
         return @ddlist;
 }
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Fiserlab Members , C<< <andras at fiserlab.org> >>
 
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-. at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
-
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.
 
 =head1 SUPPORT
 
@@ -615,9 +597,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc EnumerateSmotifCombinations
 
-
-You can also look for information at:
-
 =over 4
 
 =item * RT: CPAN's request tracker (report bugs here)
@@ -638,7 +617,6 @@ L<http://search.cpan.org/dist/./>
 
 =back
 
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2015 Fiserlab Members .
