@@ -6,9 +6,8 @@ use warnings;
 BEGIN {
     use Exporter ();
     our ( $VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
-    $VERSION = "0.1";
+    $VERSION = "0.01";
 
-    #$AUTHOR  = "Vilas Menon(vilas\@fiserlab.org )";
     @ISA = qw(Exporter);
 
     # name of the functions to export
@@ -99,7 +98,7 @@ our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
-This module consists of all subroutines that carry out geometrical calculations
+This module consists of subroutines that carry out geometrical calculations
 using the atomic coordinates obtained from a protein structure. 
 
 =head2 calc_geom 
@@ -1740,18 +1739,14 @@ sub norm2 {
     return $res;
 }
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Fiserlab Members , C<< <andras at fiserlab.org> >>
 
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-. at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
-
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.
 
 =head1 SUPPORT
 
@@ -1759,9 +1754,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc GeometricalCalculations
 
-
-You can also look for information at:
-
 =over 4
 
 =item * RT: CPAN's request tracker (report bugs here)
@@ -1782,10 +1774,6 @@ L<http://search.cpan.org/dist/./>
 
 =back
 
-
-=head1 ACKNOWLEDGEMENTS
-
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2015 Fiserlab Members .
