@@ -13,9 +13,8 @@ use Data::Dumper;
 BEGIN {
     use Exporter ();
     our ( $VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
-    $VERSION = "0.1";
+    $VERSION = "0.01";
 
-    #$AUTHOR  = "Vilas Menon(vilas\@fiserlab.org )";
     @ISA = qw(Exporter);
 
     # name of the functions to export
@@ -64,7 +63,9 @@ our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
-	Subroutines to run Psipred
+	Set of routines to run and analyze Psipred
+
+	Usage: 
 
     use Psipred;
 
@@ -74,11 +75,10 @@ our $VERSION = '0.01';
 =cut
 
 =head2 run
+
    run psipred
    /usr/local/bin/runpsipred 4wyq.fasta
    
-   input: 
-
 =cut
 
 sub run {
@@ -212,6 +212,8 @@ sub write_outfile {
     croak "SS array is requires"          unless @ss;
     croak "Smotif start residue number is required"       unless $start;
     
+    # Query chain-name is not manadatory for calculation further down.
+    # That's why we set it to A by default.   
     $chain = 'A' unless defined $chain;
 
     open(OUTFILE,">$filename");	
@@ -435,18 +437,14 @@ sub count_pdb_smotifs {
         return $smotifs;
 }
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Fiserlab Members , C<< <andras at fiserlab.org> >>
 
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-./ at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=./>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
-
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=./>.
 
 =head1 SUPPORT
 
@@ -454,9 +452,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Psipred
 
-
-You can also look for information at:
-
 =over 4
 
 =item * RT: CPAN's request tracker (report bugs here)
@@ -477,10 +472,6 @@ L<http://search.cpan.org/dist/.//>
 
 =back
 
-
-=head1 ACKNOWLEDGEMENTS
-
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2015 Fiserlab Members .
