@@ -68,7 +68,7 @@ exit;
 
 sub case_1 {
     print
-      "Step 1: Comparing chemical shifts (this step may take a while)...\n\n";
+      "Step 1: Comparing Smotifs (this step may take a while)...\n\n";
 
     my $smfile = catfile ($pdb, "$pdb.out");
 
