@@ -2,6 +2,7 @@
 use warnings;
 use strict;
 use Data::Dumper;
+use Cwd qw(cwd);
 # 
 # It runs  smotiftf pre-requisites
 #
@@ -10,7 +11,9 @@ use Data::Dumper;
 #    2. Run Psipred (- get .horiz and .ss2 files). 
 #    3. Run HHblits  and get hhr file 
 #    4. Run psi-blast and delta-blast 
+
 #
+#use lib "/home/cmadrid/test/lib/perl5/site_perl/5.8.8/";
 #use lib "/home/user/MyPerlLib/share/perl5/";
 use SmotifTF;
 
@@ -37,8 +40,6 @@ my $localrun      = $cfg->param( -block => 'localrun' );
 my $MAX_PROCESSES = $localrun->{'max_proc'};
 
 my $sequence_file;
-#my $pdb;
-#my $chain;
 my $step = 0;
 my $dir;
 my $verbose;
@@ -49,7 +50,6 @@ my $help = 0;
 # smotiftf_prereq.pl -s 4wyq.fasta -d ./
 my $result = GetOptions(
     "sequence_file=s" => \$sequence_file,  #  string
-#    "chain=s"         => \$chain,          # string
     "dir=s"           => \$dir,            # string
     "step=s"          => \$step,           # string
     "verbose"         => \$verbose,
@@ -76,6 +76,8 @@ my $dispatch_for = {
     DEFAULT => sub { print "Unknown step.\n"; }
 };
 
+my $cwd = cwd();
+
 my $func = $dispatch_for->{$step} || $dispatch_for->{DEFAULT};
 $func->();
 
@@ -90,6 +92,7 @@ sub run_psipred {
     if ($@) {
         print "Error: at run_psipred $@";
     }
+    chdir $cwd;
 }
 
 sub run_hhblits {
@@ -117,6 +120,7 @@ Writing A3M alignment to 4wyq.a3m
     if ($@) {
         print "Error: at run_hhblits $@";
     }
+    chdir $cwd;
 }
 
 sub run_hhsearch {
@@ -139,6 +143,8 @@ sub run_hhsearch {
     if ($@) {
         print "Error: at run_hhsearch $@";
     }
+    chdir $cwd;
+
 }
 
 sub run_psiblast {
@@ -160,6 +166,7 @@ sub run_psiblast {
     if ($@) {
         print "Error: at run_psiblast $@";
     }
+    chdir $cwd;
 }
 
 sub run_deltablast {
@@ -179,6 +186,7 @@ sub run_deltablast {
     if ($@) {
         print "Error: at run_deltablast $@";
     }
+    chdir $cwd;
 }
 
 #
@@ -237,6 +245,7 @@ sub reformat_psiblast_deltablast_combined_output {
     if ($@) {
         print "Error: at run_deltablast $@";
     }
+    chdir $cwd;
 }
 
 sub run_analyze_psipred {
@@ -263,6 +272,7 @@ sub run_analyze_psipred {
     if ($@) {
         print "Error: at analyze_psipred  $@";
     }
+    chdir $cwd;
 }
 
 # my $outputlogfile = $pdb_code . "_" . $chain . ".extract_loops.log";
@@ -317,6 +327,7 @@ sub generate_dynamic_database {
     
     # check_step2( $pdb, $smotifs );
     eval {
+        # chdir $dir;
         #
         # get get_smotif_definition for the :
         # hhr,  psiblast, deltablast combined (reformatted) hits
@@ -327,8 +338,8 @@ sub generate_dynamic_database {
         my $dd_path = catfile( $dir, $dd_file); 
         print "dd_file = $dd_path\n";
         my @smotif  = get_smotif_definition( $dd_path );
-        print "Smotif\n";
-        print Dumper( \@smotif );
+        # print "Smotif\n";
+        # print Dumper( \@smotif );
 
         # we need pdb chain and evalue for the
         # hhr,  psiblast, deltablast combined (reformatted) hits
@@ -366,9 +377,9 @@ sub generate_dynamic_database {
             }
             # then save it	
             my $num_mots = 0;
-            print "Start smotlist";
-            print Dumper(\@smotlist);
-            print "End smotlist";
+            #print "Start smotlist";
+            #print Dumper(\@smotlist);
+            #print "End smotlist";
             
             foreach my $href (@smotlist) {
                 my $motifname = $dd + 400000;  # dd -dynamucic databstabese entry countet # nid
@@ -395,12 +406,13 @@ sub generate_dynamic_database {
                 print OUTFILE5 "$motifname\t$pdb_code\t$chain\t$smotif_type\t$smotif_residue_start\t$loop_length\t$ss1_length\t$ss2_length\t$sequence\t$secondary_structure\t$ramachandran\t$evalue\n";
             }
             close OUTFILE5;
+            print "\nDone: Generating Dynamic databases\n";
 
     };
     if ($@) {
         print "Error: Generate Dynamic databases  $@";
     }
-
+    chdir $cwd;
 }
 
 sub execute_all {
